@@ -15,10 +15,10 @@ from ipyleaflet import (DrawControl, FullScreenControl, Map, MapStyle, Polygon,
                         WidgetControl)
 
 from . import utils
-from .ipyleaflet import (Circle, ColorizableTileLayer, Graticule,
-                         KeyBindingControl, LayersControl, StatusBarControl,
-                         allowed_colormaps)
-from .ps_tools import compute_ps
+from ._leaflet import (Circle, ColorizableTileLayer, Graticule,
+                       KeyBindingControl, LayersControl, StatusBarControl,
+                       allowed_colormaps)
+from .pstools import compute_ps
 
 
 # Generate default plotly colormap based on planck colormap
@@ -108,7 +108,7 @@ class App:
                 StatusBarControl(),
                 KeyBindingControl(keybindings=default_keybindings),
             ),
-            crs="CAR",
+            crs=dict(name="CAR", custom=False),
             center=(0, 0),
             min_zoom=-5,
             max_zoom=+5,
